.. mdinclude:: index.md

.. toctree::
   :hidden:
   :maxdepth: 2

   self
   install
   tutorials/00_Quickstart

.. toctree::
   :caption: User Guides
   :maxdepth: 2

   tutorials/01_Introduction_to_Copulas
   tutorials/02_Univariate_Distributions
   tutorials/03_Multivariate_Distributions

.. toctree::
   :caption: Advanced Usage
   :maxdepth: 2

   tutorials/04_Syntehtic_Data_for_Machine_Learning

.. toctree::
   :caption: Resources
   :hidden:
   :titlesonly:

   API Reference <api/copulas>
   contributing
   history
   authors

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
